@@ -28,7 +28,10 @@ class FileRegistry:
         elif kind == 'price_file_list':
             self.path = self.rootpath + 'Xignite/PriceFileList/' + path + '/'
         elif kind == 'xlsx':
-            self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb' + path + '/'
+            self.path = self.rootpath + 'Analysis/' + path + '/'
+            #self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb' + path + '/'
+        elif kind == 'trades':
+            self.path = self.rootpath + 'Analysis/' + path + '/'
         elif kind == 'historic':
             self.path = self.rootpath + '__Premind/6. Product-Tech/14. FraudArb/HistoricData' + path + '/'
         elif kind == 'historic_ticker':
